@@ -44,11 +44,14 @@ setMethod( "toString", "MethodDescriptor", ._toString_MethodDescriptor )
 setMethod( "toString", "FileDescriptor", ._toString_FileDescriptor )
 setMethod( "toString", "EnumValueDescriptor", ._toString_EnumValueDescriptor )
 
-setGeneric( "toJSON", function( x ){
+setGeneric( "toJSON", function( x, ... ) {
     standardGeneric( "toJSON" )
 } )
-setMethod( "toJSON", c( x = "Message" ),
-function(x) {
-    .Call( "Message__as_json", x@pointer, PACKAGE = "RProtoBuf")
+setMethod( "toJSON", c( x = "Message"),
+function(x, preserve_proto_field_names = FALSE, always_print_primitive_fields = FALSE) {
+    .Call( "Message__as_json", x@pointer,
+          preserve_proto_field_names,
+          always_print_primitive_fields,
+          PACKAGE = "RProtoBuf")
 } )
 
